# Desserts

By: Edited by: Illustrated by: Translated by:
Published By:

Licensed:

- cover.png

# Fruity

# Apple

By: Good Food Edited by: Illustrated by: Translated by:
Published By:

Licensed: CC-By 4.0

summary

Food
デザート
Pudding
Humanities

# Apple Desserts

Here are some examples:

- Apple Crumble,
- Apfelstrudel,
- Caramel Apple,
- Apple Pie,
- Apple sauce...

# Lemon

By: Good Food Edited by: Illustrated by: Translated by:
Published By:

Licensed: CC-By 4.0

summary

Food
デザート
Pudding
Humanities

- small.jpg

# Lemon Desserts

Yum!

- Lemon & Lime Crush,
- Lemon Drizzle Loaf,
- Lemon Cheesecake,
- Raspberry & Lemon Polenta Cake...

# Citrus

# Lemon

By: Good Food Edited by: Illustrated by: Translated by:
Published By:

Licensed: CC-By 4.0

summary

Food
デザート
Pudding
Humanities

- small.jpg

# Lemon Desserts

Yum!

- Lemon & Lime Crush,
- Lemon Drizzle Loaf,
- Lemon Cheesecake,
- Raspberry & Lemon Polenta Cake...

# チョコレート

By: Good Food Edited by: Illustrated by: Translated by:
Published By:

Licensed: CC-By 4.0

summary

Food
デザート
Pudding
Humanities

- small.jpg

# Chocolate Desserts

List of desserts to try:

- Chocolate Orange Tart,
- Hot Mocha Puddings,
- Chocolate and Banana French Toast,
- Chocolate Truffles...

チョコレートデザート

# Extra Stuff

By: Good Food Edited by: Illustrated by: Translated by:
Published By:

Licensed: CC-By 4.0

summary

Food
デザート
Pudding
Humanities

# Extra Stuff

This is a composite page.